@@ -9,7 +9,7 @@ mod visitor;
 
 pub mod constants;
 pub mod extensions;
-pub mod file;
+pub mod file_attrs;
 pub mod request;
 pub mod response;
 
